pub struct ApplicationEntry {
pub id: Rc<str>,
pub name: Rc<str>,
pub exec: Option<Rc<str>>,
pub exec_args: Vec<Rc<str>>,
pub icon: Option<Rc<str>>,
}Expand description
And data structure representing an application
It contains a subset of the fields from an XDG desktop entry file
Fields
id: Rc<str>The application’s id
The filename of the desktop entry file without the .desktop extension and is used
to uniquely identify an application
name: Rc<str>The application’s name
The name that is displayed to the user in the application menu, taskbar, etc.
exec: Option<Rc<str>>The application’s executable
The absolute path to the application’s executable, obtained from the Exec field in
the desktop entry file
exec_args: Vec<Rc<str>>The application’s argv as declared in the desktop entry
Tokens of the Exec= line starting from the primary binary (launcher prefixes such
as flatpak/snap/env are stripped).
Used to tell apart applications that share an exec path. For example Chromium PWAs
(distinguished by --app-id=/--app=) or user-made launcher shortcuts for the
same binary with different args.
icon: Option<Rc<str>>The application’s icon
If available, taken verbatim from the Icon field in the desktop entry file